@@ -2,6 +2,7 @@
 The wntr.graphics package contains graphic functions
 """
 from wntr.graphics.network import plot_network, plot_interactive_network, plot_leaflet_network, network_animation
+from wntr.graphics.layer import plot_valve_layer
 from wntr.graphics.curve import plot_fragility_curve, plot_pump_curve, plot_tank_volume_curve
-from wntr.graphics.color import custom_colormap
+from wntr.graphics.color import custom_colormap, random_colormap
 
