@@ -10,4 +10,5 @@ from .layer import generate_valve_layer
 from .options import Options
 from .controls import Comparison, ControlPriority, TimeOfDayCondition, \
     SimTimeCondition, ValueCondition, TankLevelCondition, RelativeCondition, \
-    OrCondition, AndCondition, ControlAction, Control, ControlManager, Rule
+    OrCondition, AndCondition, ControlAction, Control, ControlChecker, ControlChangeTracker, Rule
+from .io import to_dict, from_dict, read_inpfile, write_inpfile, read_json, write_json
\ No newline at end of file
